<img width="300px" src="https://sickrage.ca/img/logo-stacked.png" />

# 

##Sun May 24 2020 17:22:51 GMT+0000 (Coordinated Universal Time)


## Bug Fixes
  - Fixed issue #SICKRAGE-APP-52P - AttributeError for _home_display_show_mako in render_content
  ([433bc52f](https://gitlab-ci-token:aX13WxCRWocP-hXBKsvy@git.sickrage.ca/SiCKRAGE/sickrage/commit/433bc52f25d98c9f9d9e3c1d730051b89395f3c8))




## Refactor
  - Refactored web server to start right after config is loaded
  ([dff5d2ff](https://gitlab-ci-token:aX13WxCRWocP-hXBKsvy@git.sickrage.ca/SiCKRAGE/sickrage/commit/dff5d2ff8a302a6f20d13afe699ac787c9289759))
  - Refactored mako templates to be looked up and stored into template dict attached to tornado app settings
  ([60ac65d2](https://gitlab-ci-token:aX13WxCRWocP-hXBKsvy@git.sickrage.ca/SiCKRAGE/sickrage/commit/60ac65d283639628a9a2ebb45f246ee4b78e3f97))




